@@ -231,9 +231,11 @@ sAppendN(&sbOut, "  double nd = (double) n;\n", 26);
 sAppendN(&sbOut, "  double ktr = (nd+1)/mtt;\n", 27);
 sAppendN(&sbOut, "  double lktr = _safe_log(nd+1)-_safe_log(mtt);\n", 48);
 sAppendN(&sbOut, "  double tlast = _solveData->subjects[id].tlastS[cmt];\n", 55);
+sAppendN(&sbOut, "  double dose = _solveData->subjects[id].curDoseS[cmt];\n", 56);
+sAppendN(&sbOut, "  if (ISNA(dose)) dose = 0.0;\n", 30);
 sAppendN(&sbOut, "  if (ISNA(tlast)) tlast = 0.0;\n", 32);
 sAppendN(&sbOut, "  double tad = (t-tlast);\n", 26);
-sAppendN(&sbOut, "  return exp(_safe_log(bio*(_solveData->subjects[id].curDoseS[cmt]))+lktr+n*(lktr+_safe_log(tad))-ktr*(tad)-lgamma1p(nd));\n", 123);
+sAppendN(&sbOut, "  return exp(_safe_log(bio*dose)+lktr+n*(lktr+_safe_log(tad))-ktr*(tad)-lgamma1p(nd));\n", 87);
 sAppendN(&sbOut, "}\n", 2);
 sAppendN(&sbOut, "double _transit3P(int cmt, double t, unsigned int id, double n, double mtt){\n", 77);
 sAppendN(&sbOut, "  double nd = (double) n;\n", 26);
@@ -243,6 +245,7 @@ sAppendN(&sbOut, "  double tlast = _solveData->subjects[id].tlastS[cmt];\n", 55)
 sAppendN(&sbOut, "  if (ISNA(tlast)) tlast = 0.0;\n", 32);
 sAppendN(&sbOut, "  double tad = t-tlast;\n", 24);
 sAppendN(&sbOut, "  double podo = _solveData->subjects[id].curDoseS[cmt];\n", 56);
+sAppendN(&sbOut, "  if (ISNA(podo)) podo = 0.0;\n", 30);
 sAppendN(&sbOut, "  return exp(_safe_log(podo)+lktr+n*(lktr+_safe_log(tad))-ktr*(tad)-lgamma1p(nd));\n", 83);
 sAppendN(&sbOut, "}\n", 2);
 sAppendN(&sbOut, "void _assignFuns0(void) {\n", 26);
